/* Lithuanian translation for the jQuery Timepicker Addon */
/* Written by Irmantas Šiupšinskas */
(function($) {
	$.timepicker.regional['lt'] = {
		timeOnlyTitle: 'Pasirinkite laiką',
		timeText: 'Laikas',
		hourText: 'Valandos',
		minuteText: 'Minutės',
		secondText: 'Sekundės',
		millisecText: 'Milisekundės',
		timezoneText: 'Laiko zona',
		currentText: 'Dabar',
		closeText: 'Uždaryti',
		timeFormat: 'hh:mm',
		amNames: ['priešpiet', 'AM', 'A'],
		pmNames: ['popiet', 'PM', 'P'],
		ampm: false
	};
	$.timepicker.setDefaults($.timepicker.regional['lt']);
})(jQuery);
